Class: OneMsgSdk::CallingSettingsCallingSipServersInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/one_msg_sdk/models/calling_settings_calling_sip_servers_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CallingSettingsCallingSipServersInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/one_msg_sdk/models/calling_settings_calling_sip_servers_inner.rb', line 74

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OneMsgSdk::CallingSettingsCallingSipServersInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OneMsgSdk::CallingSettingsCallingSipServersInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'hostname')
    self.hostname = attributes[:'hostname']
  end

  if attributes.key?(:'port')
    self.port = attributes[:'port']
  end

  if attributes.key?(:'request_uri_user_params')
    if (value = attributes[:'request_uri_user_params']).is_a?(Hash)
      self.request_uri_user_params = value
    end
  end

  if attributes.key?(:'sip_user_password')
    self.sip_user_password = attributes[:'sip_user_password']
  end

  if attributes.key?(:'password')
    self.password = attributes[:'password']
  end

  if attributes.key?(:'app_id')
    self.app_id = attributes[:'app_id']
  end
end

Instance Attribute Details

#app_idObject

Returns the value of attribute app_id.



30
31
32
# File 'lib/one_msg_sdk/models/calling_settings_calling_sip_servers_inner.rb', line 30

def app_id
  @app_id
end

#hostnameObject

Returns the value of attribute hostname.



18
19
20
# File 'lib/one_msg_sdk/models/calling_settings_calling_sip_servers_inner.rb', line 18

def hostname
  @hostname
end

#passwordObject

Alternate password field name from some Meta responses



28
29
30
# File 'lib/one_msg_sdk/models/calling_settings_calling_sip_servers_inner.rb', line 28

def password
  @password
end

#portObject

Returns the value of attribute port.



20
21
22
# File 'lib/one_msg_sdk/models/calling_settings_calling_sip_servers_inner.rb', line 20

def port
  @port
end

#request_uri_user_paramsObject

Returns the value of attribute request_uri_user_params.



22
23
24
# File 'lib/one_msg_sdk/models/calling_settings_calling_sip_servers_inner.rb', line 22

def request_uri_user_params
  @request_uri_user_params
end

#sip_user_passwordObject

Present on GET when SIP credentials are returned by Meta



25
26
27
# File 'lib/one_msg_sdk/models/calling_settings_calling_sip_servers_inner.rb', line 25

def sip_user_password
  @sip_user_password
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/one_msg_sdk/models/calling_settings_calling_sip_servers_inner.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/one_msg_sdk/models/calling_settings_calling_sip_servers_inner.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
42
# File 'lib/one_msg_sdk/models/calling_settings_calling_sip_servers_inner.rb', line 33

def self.attribute_map
  {
    :'hostname' => :'hostname',
    :'port' => :'port',
    :'request_uri_user_params' => :'request_uri_user_params',
    :'sip_user_password' => :'sip_user_password',
    :'password' => :'password',
    :'app_id' => :'app_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/one_msg_sdk/models/calling_settings_calling_sip_servers_inner.rb', line 158

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
# File 'lib/one_msg_sdk/models/calling_settings_calling_sip_servers_inner.rb', line 67

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
64
# File 'lib/one_msg_sdk/models/calling_settings_calling_sip_servers_inner.rb', line 55

def self.openapi_types
  {
    :'hostname' => :'String',
    :'port' => :'Integer',
    :'request_uri_user_params' => :'Hash<String, String>',
    :'sip_user_password' => :'String',
    :'password' => :'String',
    :'app_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



132
133
134
135
136
137
138
139
140
141
# File 'lib/one_msg_sdk/models/calling_settings_calling_sip_servers_inner.rb', line 132

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      hostname == o.hostname &&
      port == o.port &&
      request_uri_user_params == o.request_uri_user_params &&
      sip_user_password == o.sip_user_password &&
      password == o.password &&
      app_id == o.app_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


145
146
147
# File 'lib/one_msg_sdk/models/calling_settings_calling_sip_servers_inner.rb', line 145

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



151
152
153
# File 'lib/one_msg_sdk/models/calling_settings_calling_sip_servers_inner.rb', line 151

def hash
  [hostname, port, request_uri_user_params, sip_user_password, password, app_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



117
118
119
120
121
# File 'lib/one_msg_sdk/models/calling_settings_calling_sip_servers_inner.rb', line 117

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/one_msg_sdk/models/calling_settings_calling_sip_servers_inner.rb', line 180

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



125
126
127
128
# File 'lib/one_msg_sdk/models/calling_settings_calling_sip_servers_inner.rb', line 125

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end