Class: OneMsgSdk::InitiateCallRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OneMsgSdk::InitiateCallRequest
- Defined in:
- lib/one_msg_sdk/models/initiate_call_request.rb
Overview
Call action payload for POST /initiateCall (proxies upstream POST /calling/calls). Despite the path name, this endpoint handles all call actions — not only outbound connect. ## Required fields by action | action | Required | session | |--------|----------|-----------| | connect (outbound) | messaging_product, to, action | sdp_type: offer + business WebRTC SDP | | pre_accept | messaging_product, call_id, action | sdp_type: answer (WebRTC-generated) | | accept | messaging_product, call_id, action | sdp_type: answer (WebRTC-generated) | | reject | messaging_product, call_id, action | none | | terminate | messaging_product, call_id, action | none | Critical: For pre_accept / accept, session.sdp must be a WebRTC-generated SDP answer. Do not echo Meta's offer SDP back. Postman alone cannot establish real media — you need a WebRTC (or SIP) stack.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#action ⇒ Object
Call control action.
-
#biz_opaque_callback_data ⇒ Object
Optional opaque string echoed on later call webhooks for correlation.
-
#call_id ⇒ Object
WhatsApp call id from the inbound/outbound calls webhook (
calls[].id). -
#messaging_product ⇒ Object
Must be
whatsapp. -
#session ⇒ Object
Returns the value of attribute session.
-
#to ⇒ Object
Recipient WhatsApp user phone (digits, country code, no +).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InitiateCallRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ InitiateCallRequest
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/one_msg_sdk/models/initiate_call_request.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OneMsgSdk::InitiateCallRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OneMsgSdk::InitiateCallRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'messaging_product') self.messaging_product = attributes[:'messaging_product'] else self.messaging_product = nil end if attributes.key?(:'action') self.action = attributes[:'action'] else self.action = nil end if attributes.key?(:'call_id') self.call_id = attributes[:'call_id'] end if attributes.key?(:'to') self.to = attributes[:'to'] end if attributes.key?(:'biz_opaque_callback_data') self.biz_opaque_callback_data = attributes[:'biz_opaque_callback_data'] end if attributes.key?(:'session') self.session = attributes[:'session'] end end |
Instance Attribute Details
#action ⇒ Object
Call control action
23 24 25 |
# File 'lib/one_msg_sdk/models/initiate_call_request.rb', line 23 def action @action end |
#biz_opaque_callback_data ⇒ Object
Optional opaque string echoed on later call webhooks for correlation
32 33 34 |
# File 'lib/one_msg_sdk/models/initiate_call_request.rb', line 32 def biz_opaque_callback_data @biz_opaque_callback_data end |
#call_id ⇒ Object
WhatsApp call id from the inbound/outbound calls webhook (calls[].id). Required for pre_accept, accept, reject, terminate.
26 27 28 |
# File 'lib/one_msg_sdk/models/initiate_call_request.rb', line 26 def call_id @call_id end |
#messaging_product ⇒ Object
Must be whatsapp
20 21 22 |
# File 'lib/one_msg_sdk/models/initiate_call_request.rb', line 20 def messaging_product @messaging_product end |
#session ⇒ Object
Returns the value of attribute session.
34 35 36 |
# File 'lib/one_msg_sdk/models/initiate_call_request.rb', line 34 def session @session end |
#to ⇒ Object
Recipient WhatsApp user phone (digits, country code, no +). Required for outbound connect.
29 30 31 |
# File 'lib/one_msg_sdk/models/initiate_call_request.rb', line 29 def to @to end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/one_msg_sdk/models/initiate_call_request.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/one_msg_sdk/models/initiate_call_request.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/one_msg_sdk/models/initiate_call_request.rb', line 59 def self.attribute_map { :'messaging_product' => :'messaging_product', :'action' => :'action', :'call_id' => :'call_id', :'to' => :'to', :'biz_opaque_callback_data' => :'biz_opaque_callback_data', :'session' => :'session' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/one_msg_sdk/models/initiate_call_request.rb', line 239 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
93 94 95 96 |
# File 'lib/one_msg_sdk/models/initiate_call_request.rb', line 93 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/one_msg_sdk/models/initiate_call_request.rb', line 81 def self.openapi_types { :'messaging_product' => :'String', :'action' => :'String', :'call_id' => :'String', :'to' => :'String', :'biz_opaque_callback_data' => :'String', :'session' => :'InitiateCallRequestSession' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
213 214 215 216 217 218 219 220 221 222 |
# File 'lib/one_msg_sdk/models/initiate_call_request.rb', line 213 def ==(o) return true if self.equal?(o) self.class == o.class && messaging_product == o.messaging_product && action == o.action && call_id == o.call_id && to == o.to && biz_opaque_callback_data == o.biz_opaque_callback_data && session == o.session end |
#eql?(o) ⇒ Boolean
226 227 228 |
# File 'lib/one_msg_sdk/models/initiate_call_request.rb', line 226 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
232 233 234 |
# File 'lib/one_msg_sdk/models/initiate_call_request.rb', line 232 def hash [messaging_product, action, call_id, to, biz_opaque_callback_data, session].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/one_msg_sdk/models/initiate_call_request.rb', line 145 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @messaging_product.nil? invalid_properties.push('invalid value for "messaging_product", messaging_product cannot be nil.') end if @action.nil? invalid_properties.push('invalid value for "action", action cannot be nil.') end if !@biz_opaque_callback_data.nil? && @biz_opaque_callback_data.to_s.length > 512 invalid_properties.push('invalid value for "biz_opaque_callback_data", the character length must be smaller than or equal to 512.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/one_msg_sdk/models/initiate_call_request.rb', line 261 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/one_msg_sdk/models/initiate_call_request.rb', line 165 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @messaging_product.nil? messaging_product_validator = EnumAttributeValidator.new('String', ["whatsapp"]) return false unless messaging_product_validator.valid?(@messaging_product) return false if @action.nil? action_validator = EnumAttributeValidator.new('String', ["connect", "pre_accept", "accept", "reject", "terminate"]) return false unless action_validator.valid?(@action) return false if !@biz_opaque_callback_data.nil? && @biz_opaque_callback_data.to_s.length > 512 true end |