Class: OneMsgSdk::ProfileInfo
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OneMsgSdk::ProfileInfo
- Defined in:
- lib/one_msg_sdk/models/profile_info.rb
Overview
WhatsApp Business profile information
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#about ⇒ Object
Profile's About section.
-
#address ⇒ Object
Address of the business.
-
#description ⇒ Object
Description of the business.
-
#email ⇒ Object
Business email.
-
#phone ⇒ Object
Linked phone number.
-
#photo ⇒ Object
Profile photo URL.
-
#vertical ⇒ Object
Industry of the business.
-
#websites ⇒ Object
Returns the value of attribute websites.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ProfileInfo
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ProfileInfo
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/one_msg_sdk/models/profile_info.rb', line 110 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OneMsgSdk::ProfileInfo` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OneMsgSdk::ProfileInfo`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'about') self.about = attributes[:'about'] end if attributes.key?(:'address') self.address = attributes[:'address'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'phone') self.phone = attributes[:'phone'] end if attributes.key?(:'vertical') self.vertical = attributes[:'vertical'] end if attributes.key?(:'photo') self.photo = attributes[:'photo'] end if attributes.key?(:'websites') if (value = attributes[:'websites']).is_a?(Array) self.websites = value end end end |
Instance Attribute Details
#about ⇒ Object
Profile's About section
20 21 22 |
# File 'lib/one_msg_sdk/models/profile_info.rb', line 20 def about @about end |
#address ⇒ Object
Address of the business
23 24 25 |
# File 'lib/one_msg_sdk/models/profile_info.rb', line 23 def address @address end |
#description ⇒ Object
Description of the business
26 27 28 |
# File 'lib/one_msg_sdk/models/profile_info.rb', line 26 def description @description end |
#email ⇒ Object
Business email
29 30 31 |
# File 'lib/one_msg_sdk/models/profile_info.rb', line 29 def email @email end |
#phone ⇒ Object
Linked phone number
32 33 34 |
# File 'lib/one_msg_sdk/models/profile_info.rb', line 32 def phone @phone end |
#photo ⇒ Object
Profile photo URL
38 39 40 |
# File 'lib/one_msg_sdk/models/profile_info.rb', line 38 def photo @photo end |
#vertical ⇒ Object
Industry of the business
35 36 37 |
# File 'lib/one_msg_sdk/models/profile_info.rb', line 35 def vertical @vertical end |
#websites ⇒ Object
Returns the value of attribute websites.
40 41 42 |
# File 'lib/one_msg_sdk/models/profile_info.rb', line 40 def websites @websites end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
79 80 81 |
# File 'lib/one_msg_sdk/models/profile_info.rb', line 79 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
84 85 86 |
# File 'lib/one_msg_sdk/models/profile_info.rb', line 84 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/one_msg_sdk/models/profile_info.rb', line 65 def self.attribute_map { :'about' => :'about', :'address' => :'address', :'description' => :'description', :'email' => :'email', :'phone' => :'phone', :'vertical' => :'vertical', :'photo' => :'photo', :'websites' => :'websites' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/one_msg_sdk/models/profile_info.rb', line 216 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
103 104 105 106 |
# File 'lib/one_msg_sdk/models/profile_info.rb', line 103 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/one_msg_sdk/models/profile_info.rb', line 89 def self.openapi_types { :'about' => :'String', :'address' => :'String', :'description' => :'String', :'email' => :'String', :'phone' => :'String', :'vertical' => :'String', :'photo' => :'String', :'websites' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/one_msg_sdk/models/profile_info.rb', line 188 def ==(o) return true if self.equal?(o) self.class == o.class && about == o.about && address == o.address && description == o.description && email == o.email && phone == o.phone && vertical == o.vertical && photo == o.photo && websites == o.websites end |
#eql?(o) ⇒ Boolean
203 204 205 |
# File 'lib/one_msg_sdk/models/profile_info.rb', line 203 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
209 210 211 |
# File 'lib/one_msg_sdk/models/profile_info.rb', line 209 def hash [about, address, description, email, phone, vertical, photo, websites].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
161 162 163 164 165 |
# File 'lib/one_msg_sdk/models/profile_info.rb', line 161 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/one_msg_sdk/models/profile_info.rb', line 238 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
169 170 171 172 173 174 |
# File 'lib/one_msg_sdk/models/profile_info.rb', line 169 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' vertical_validator = EnumAttributeValidator.new('String', ["Automotive", "Beauty, Spa and Salon", "Clothing and Apparel", "Education", "Entertainment", "Event Planning and Service", "Finance and Banking", "Food and Grocery", "Public Service", "Hotel and Lodging", "Medical and Health", "Non-profit", "Professional Services", "Shopping and Retail", "Travel and Transportation", "Restaurant", "Other"]) return false unless vertical_validator.valid?(@vertical) true end |