Class: OneMsgSdk::SendCtaUrlRequest

Inherits:
ApiModelBase show all
Defined in:
lib/one_msg_sdk/models/send_cta_url_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SendCtaUrlRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/one_msg_sdk/models/send_cta_url_request.rb', line 81

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OneMsgSdk::SendCtaUrlRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OneMsgSdk::SendCtaUrlRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'phone')
    self.phone = attributes[:'phone']
  end

  if attributes.key?(:'chat_id')
    self.chat_id = attributes[:'chat_id']
  end

  if attributes.key?(:'body')
    self.body = attributes[:'body']
  else
    self.body = nil
  end

  if attributes.key?(:'display_text')
    self.display_text = attributes[:'display_text']
  else
    self.display_text = nil
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  else
    self.url = nil
  end

  if attributes.key?(:'header')
    if (value = attributes[:'header']).is_a?(Hash)
      self.header = value
    end
  end

  if attributes.key?(:'footer')
    self.footer = attributes[:'footer']
  end

  if attributes.key?(:'quoted_msg_id')
    self.quoted_msg_id = attributes[:'quoted_msg_id']
  end
end

Instance Attribute Details

#bodyObject

Returns the value of attribute body.



22
23
24
# File 'lib/one_msg_sdk/models/send_cta_url_request.rb', line 22

def body
  @body
end

#chat_idObject

Returns the value of attribute chat_id.



20
21
22
# File 'lib/one_msg_sdk/models/send_cta_url_request.rb', line 20

def chat_id
  @chat_id
end

#display_textObject

Button label



25
26
27
# File 'lib/one_msg_sdk/models/send_cta_url_request.rb', line 25

def display_text
  @display_text
end

Returns the value of attribute footer.



31
32
33
# File 'lib/one_msg_sdk/models/send_cta_url_request.rb', line 31

def footer
  @footer
end

#headerObject

Returns the value of attribute header.



29
30
31
# File 'lib/one_msg_sdk/models/send_cta_url_request.rb', line 29

def header
  @header
end

#phoneObject

Returns the value of attribute phone.



18
19
20
# File 'lib/one_msg_sdk/models/send_cta_url_request.rb', line 18

def phone
  @phone
end

#quoted_msg_idObject

Returns the value of attribute quoted_msg_id.



33
34
35
# File 'lib/one_msg_sdk/models/send_cta_url_request.rb', line 33

def quoted_msg_id
  @quoted_msg_id
end

#urlObject

Returns the value of attribute url.



27
28
29
# File 'lib/one_msg_sdk/models/send_cta_url_request.rb', line 27

def url
  @url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/one_msg_sdk/models/send_cta_url_request.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/one_msg_sdk/models/send_cta_url_request.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/one_msg_sdk/models/send_cta_url_request.rb', line 36

def self.attribute_map
  {
    :'phone' => :'phone',
    :'chat_id' => :'chatId',
    :'body' => :'body',
    :'display_text' => :'displayText',
    :'url' => :'url',
    :'header' => :'header',
    :'footer' => :'footer',
    :'quoted_msg_id' => :'quotedMsgId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/one_msg_sdk/models/send_cta_url_request.rb', line 226

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
# File 'lib/one_msg_sdk/models/send_cta_url_request.rb', line 74

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/one_msg_sdk/models/send_cta_url_request.rb', line 60

def self.openapi_types
  {
    :'phone' => :'Integer',
    :'chat_id' => :'String',
    :'body' => :'String',
    :'display_text' => :'String',
    :'url' => :'String',
    :'header' => :'Hash<String, Object>',
    :'footer' => :'String',
    :'quoted_msg_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/one_msg_sdk/models/send_cta_url_request.rb', line 198

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      phone == o.phone &&
      chat_id == o.chat_id &&
      body == o.body &&
      display_text == o.display_text &&
      url == o.url &&
      header == o.header &&
      footer == o.footer &&
      quoted_msg_id == o.quoted_msg_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


213
214
215
# File 'lib/one_msg_sdk/models/send_cta_url_request.rb', line 213

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



219
220
221
# File 'lib/one_msg_sdk/models/send_cta_url_request.rb', line 219

def hash
  [phone, chat_id, body, display_text, url, header, footer, quoted_msg_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/one_msg_sdk/models/send_cta_url_request.rb', line 138

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @body.nil?
    invalid_properties.push('invalid value for "body", body cannot be nil.')
  end

  if @display_text.nil?
    invalid_properties.push('invalid value for "display_text", display_text cannot be nil.')
  end

  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/one_msg_sdk/models/send_cta_url_request.rb', line 248

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



158
159
160
161
162
163
164
# File 'lib/one_msg_sdk/models/send_cta_url_request.rb', line 158

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @body.nil?
  return false if @display_text.nil?
  return false if @url.nil?
  true
end