Class: OneMsgSdk::SendMessageRequest

Inherits:
ApiModelBase show all
Defined in:
lib/one_msg_sdk/models/send_message_request.rb

Overview

Request body for sending a text message

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SendMessageRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/one_msg_sdk/models/send_message_request.rb', line 69

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OneMsgSdk::SendMessageRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OneMsgSdk::SendMessageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'body')
    self.body = attributes[:'body']
  else
    self.body = nil
  end

  if attributes.key?(:'quoted_msg_id')
    self.quoted_msg_id = attributes[:'quoted_msg_id']
  end

  if attributes.key?(:'chat_id')
    self.chat_id = attributes[:'chat_id']
  end

  if attributes.key?(:'phone')
    self.phone = attributes[:'phone']
  end
end

Instance Attribute Details

#bodyObject

Message text, UTF-8 or UTF-16 string with emoji



20
21
22
# File 'lib/one_msg_sdk/models/send_message_request.rb', line 20

def body
  @body
end

#chat_idObject

Chat ID in format: phone@c.us (individual) or phone@g.us (group)



26
27
28
# File 'lib/one_msg_sdk/models/send_message_request.rb', line 26

def chat_id
  @chat_id
end

#phoneObject

Phone number starting with country code (alternative to chatId)



29
30
31
# File 'lib/one_msg_sdk/models/send_message_request.rb', line 29

def phone
  @phone
end

#quoted_msg_idObject

Message ID to quote/reply to (Cloud API wamid)



23
24
25
# File 'lib/one_msg_sdk/models/send_message_request.rb', line 23

def quoted_msg_id
  @quoted_msg_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



42
43
44
# File 'lib/one_msg_sdk/models/send_message_request.rb', line 42

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



47
48
49
# File 'lib/one_msg_sdk/models/send_message_request.rb', line 47

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
# File 'lib/one_msg_sdk/models/send_message_request.rb', line 32

def self.attribute_map
  {
    :'body' => :'body',
    :'quoted_msg_id' => :'quotedMsgId',
    :'chat_id' => :'chatId',
    :'phone' => :'phone'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/one_msg_sdk/models/send_message_request.rb', line 246

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



62
63
64
65
# File 'lib/one_msg_sdk/models/send_message_request.rb', line 62

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



52
53
54
55
56
57
58
59
# File 'lib/one_msg_sdk/models/send_message_request.rb', line 52

def self.openapi_types
  {
    :'body' => :'String',
    :'quoted_msg_id' => :'String',
    :'chat_id' => :'String',
    :'phone' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



222
223
224
225
226
227
228
229
# File 'lib/one_msg_sdk/models/send_message_request.rb', line 222

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      body == o.body &&
      quoted_msg_id == o.quoted_msg_id &&
      chat_id == o.chat_id &&
      phone == o.phone
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


233
234
235
# File 'lib/one_msg_sdk/models/send_message_request.rb', line 233

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



239
240
241
# File 'lib/one_msg_sdk/models/send_message_request.rb', line 239

def hash
  [body, quoted_msg_id, chat_id, phone].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/one_msg_sdk/models/send_message_request.rb', line 104

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @body.nil?
    invalid_properties.push('invalid value for "body", body cannot be nil.')
  end

  if @body.to_s.length > 4096
    invalid_properties.push('invalid value for "body", the character length must be smaller than or equal to 4096.')
  end

  if @body.to_s.length < 1
    invalid_properties.push('invalid value for "body", the character length must be greater than or equal to 1.')
  end

  pattern = Regexp.new(/^wamid\..+$/)
  if !@quoted_msg_id.nil? && @quoted_msg_id !~ pattern
    invalid_properties.push("invalid value for \"quoted_msg_id\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^[0-9]+@[cg]\.us$/)
  if !@chat_id.nil? && @chat_id !~ pattern
    invalid_properties.push("invalid value for \"chat_id\", must conform to the pattern #{pattern}.")
  end

  if !@phone.nil? && @phone > 999999999999999
    invalid_properties.push('invalid value for "phone", must be smaller than or equal to 999999999999999.')
  end

  if !@phone.nil? && @phone < 1000000000
    invalid_properties.push('invalid value for "phone", must be greater than or equal to 1000000000.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/one_msg_sdk/models/send_message_request.rb', line 268

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



142
143
144
145
146
147
148
149
150
151
152
# File 'lib/one_msg_sdk/models/send_message_request.rb', line 142

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @body.nil?
  return false if @body.to_s.length > 4096
  return false if @body.to_s.length < 1
  return false if !@quoted_msg_id.nil? && @quoted_msg_id !~ Regexp.new(/^wamid\..+$/)
  return false if !@chat_id.nil? && @chat_id !~ Regexp.new(/^[0-9]+@[cg]\.us$/)
  return false if !@phone.nil? && @phone > 999999999999999
  return false if !@phone.nil? && @phone < 1000000000
  true
end