Class: OneMsgSdk::UpdateMeRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OneMsgSdk::UpdateMeRequest
- Defined in:
- lib/one_msg_sdk/models/update_me_request.rb
Instance Attribute Summary collapse
-
#about ⇒ Object
Profile About section.
-
#address ⇒ Object
Returns the value of attribute address.
-
#description ⇒ Object
Business description (max 256 characters).
-
#email ⇒ Object
Returns the value of attribute email.
-
#photo ⇒ Object
HTTPS URL or data:image/...;base64,...
-
#vertical ⇒ Object
Industry of the business.
-
#websites ⇒ Object
Returns the value of attribute websites.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateMeRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateMeRequest
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/one_msg_sdk/models/update_me_request.rb', line 80 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OneMsgSdk::UpdateMeRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OneMsgSdk::UpdateMeRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'about') self.about = attributes[:'about'] end if attributes.key?(:'address') self.address = attributes[:'address'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'vertical') self.vertical = attributes[:'vertical'] end if attributes.key?(:'photo') self.photo = attributes[:'photo'] end if attributes.key?(:'websites') if (value = attributes[:'websites']).is_a?(Array) self.websites = value end end end |
Instance Attribute Details
#about ⇒ Object
Profile About section
19 20 21 |
# File 'lib/one_msg_sdk/models/update_me_request.rb', line 19 def about @about end |
#address ⇒ Object
Returns the value of attribute address.
21 22 23 |
# File 'lib/one_msg_sdk/models/update_me_request.rb', line 21 def address @address end |
#description ⇒ Object
Business description (max 256 characters)
24 25 26 |
# File 'lib/one_msg_sdk/models/update_me_request.rb', line 24 def description @description end |
#email ⇒ Object
Returns the value of attribute email.
26 27 28 |
# File 'lib/one_msg_sdk/models/update_me_request.rb', line 26 def email @email end |
#photo ⇒ Object
HTTPS URL or data:image/...;base64,... payload
32 33 34 |
# File 'lib/one_msg_sdk/models/update_me_request.rb', line 32 def photo @photo end |
#vertical ⇒ Object
Industry of the business
29 30 31 |
# File 'lib/one_msg_sdk/models/update_me_request.rb', line 29 def vertical @vertical end |
#websites ⇒ Object
Returns the value of attribute websites.
34 35 36 |
# File 'lib/one_msg_sdk/models/update_me_request.rb', line 34 def websites @websites end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/one_msg_sdk/models/update_me_request.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/one_msg_sdk/models/update_me_request.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/one_msg_sdk/models/update_me_request.rb', line 37 def self.attribute_map { :'about' => :'about', :'address' => :'address', :'description' => :'description', :'email' => :'email', :'vertical' => :'vertical', :'photo' => :'photo', :'websites' => :'websites' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/one_msg_sdk/models/update_me_request.rb', line 169 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
73 74 75 76 |
# File 'lib/one_msg_sdk/models/update_me_request.rb', line 73 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/one_msg_sdk/models/update_me_request.rb', line 60 def self.openapi_types { :'about' => :'String', :'address' => :'String', :'description' => :'String', :'email' => :'String', :'vertical' => :'String', :'photo' => :'String', :'websites' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/one_msg_sdk/models/update_me_request.rb', line 142 def ==(o) return true if self.equal?(o) self.class == o.class && about == o.about && address == o.address && description == o.description && email == o.email && vertical == o.vertical && photo == o.photo && websites == o.websites end |
#eql?(o) ⇒ Boolean
156 157 158 |
# File 'lib/one_msg_sdk/models/update_me_request.rb', line 156 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
162 163 164 |
# File 'lib/one_msg_sdk/models/update_me_request.rb', line 162 def hash [about, address, description, email, vertical, photo, websites].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
127 128 129 130 131 |
# File 'lib/one_msg_sdk/models/update_me_request.rb', line 127 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/one_msg_sdk/models/update_me_request.rb', line 191 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
135 136 137 138 |
# File 'lib/one_msg_sdk/models/update_me_request.rb', line 135 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |