Class: OneMsgSdk::CallingSettingsCalling
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OneMsgSdk::CallingSettingsCalling
- Defined in:
- lib/one_msg_sdk/models/calling_settings_calling.rb
Overview
Calling feature configuration for the business phone number
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#audio ⇒ Object
Returns the value of attribute audio.
-
#call_hours ⇒ Object
Returns the value of attribute call_hours.
-
#call_icon_visibility ⇒ Object
Controls call icon visibility in the WhatsApp client.
-
#call_icons ⇒ Object
Call icon country restrictions (response-only).
-
#callback_permission_status ⇒ Object
When ENABLED, a user who calls your business automatically grants call permission for business-initiated callbacks (subject to Meta rules).
-
#ip_addresses ⇒ Object
Meta media IP ranges (response-only).
-
#restrictions ⇒ Object
Calling restrictions (response-only).
-
#sip ⇒ Object
Returns the value of attribute sip.
-
#srtp_key_exchange_protocol ⇒ Object
SRTP key exchange.
-
#status ⇒ Object
Enable or disable Calling API on this number.
-
#video ⇒ Object
Returns the value of attribute video.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CallingSettingsCalling
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CallingSettingsCalling
Initializes the object
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/one_msg_sdk/models/calling_settings_calling.rb', line 122 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OneMsgSdk::CallingSettingsCalling` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OneMsgSdk::CallingSettingsCalling`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'call_icon_visibility') self.call_icon_visibility = attributes[:'call_icon_visibility'] end if attributes.key?(:'callback_permission_status') self. = attributes[:'callback_permission_status'] end if attributes.key?(:'srtp_key_exchange_protocol') self.srtp_key_exchange_protocol = attributes[:'srtp_key_exchange_protocol'] end if attributes.key?(:'call_hours') self.call_hours = attributes[:'call_hours'] end if attributes.key?(:'sip') self.sip = attributes[:'sip'] end if attributes.key?(:'video') self.video = attributes[:'video'] end if attributes.key?(:'audio') self.audio = attributes[:'audio'] end if attributes.key?(:'restrictions') if (value = attributes[:'restrictions']).is_a?(Hash) self.restrictions = value end end if attributes.key?(:'ip_addresses') if (value = attributes[:'ip_addresses']).is_a?(Hash) self.ip_addresses = value end end if attributes.key?(:'call_icons') if (value = attributes[:'call_icons']).is_a?(Hash) self.call_icons = value end end end |
Instance Attribute Details
#audio ⇒ Object
Returns the value of attribute audio.
37 38 39 |
# File 'lib/one_msg_sdk/models/calling_settings_calling.rb', line 37 def audio @audio end |
#call_hours ⇒ Object
Returns the value of attribute call_hours.
31 32 33 |
# File 'lib/one_msg_sdk/models/calling_settings_calling.rb', line 31 def call_hours @call_hours end |
#call_icon_visibility ⇒ Object
Controls call icon visibility in the WhatsApp client
23 24 25 |
# File 'lib/one_msg_sdk/models/calling_settings_calling.rb', line 23 def call_icon_visibility @call_icon_visibility end |
#call_icons ⇒ Object
Call icon country restrictions (response-only)
46 47 48 |
# File 'lib/one_msg_sdk/models/calling_settings_calling.rb', line 46 def call_icons @call_icons end |
#callback_permission_status ⇒ Object
When ENABLED, a user who calls your business automatically grants call permission for business-initiated callbacks (subject to Meta rules).
26 27 28 |
# File 'lib/one_msg_sdk/models/calling_settings_calling.rb', line 26 def @callback_permission_status end |
#ip_addresses ⇒ Object
Meta media IP ranges (response-only)
43 44 45 |
# File 'lib/one_msg_sdk/models/calling_settings_calling.rb', line 43 def ip_addresses @ip_addresses end |
#restrictions ⇒ Object
Calling restrictions (response-only)
40 41 42 |
# File 'lib/one_msg_sdk/models/calling_settings_calling.rb', line 40 def restrictions @restrictions end |
#sip ⇒ Object
Returns the value of attribute sip.
33 34 35 |
# File 'lib/one_msg_sdk/models/calling_settings_calling.rb', line 33 def sip @sip end |
#srtp_key_exchange_protocol ⇒ Object
SRTP key exchange. DTLS is default/recommended. SDES is only valid when SIP signaling is enabled.
29 30 31 |
# File 'lib/one_msg_sdk/models/calling_settings_calling.rb', line 29 def srtp_key_exchange_protocol @srtp_key_exchange_protocol end |
#status ⇒ Object
Enable or disable Calling API on this number
20 21 22 |
# File 'lib/one_msg_sdk/models/calling_settings_calling.rb', line 20 def status @status end |
#video ⇒ Object
Returns the value of attribute video.
35 36 37 |
# File 'lib/one_msg_sdk/models/calling_settings_calling.rb', line 35 def video @video end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
88 89 90 |
# File 'lib/one_msg_sdk/models/calling_settings_calling.rb', line 88 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
93 94 95 |
# File 'lib/one_msg_sdk/models/calling_settings_calling.rb', line 93 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/one_msg_sdk/models/calling_settings_calling.rb', line 71 def self.attribute_map { :'status' => :'status', :'call_icon_visibility' => :'call_icon_visibility', :'callback_permission_status' => :'callback_permission_status', :'srtp_key_exchange_protocol' => :'srtp_key_exchange_protocol', :'call_hours' => :'call_hours', :'sip' => :'sip', :'video' => :'video', :'audio' => :'audio', :'restrictions' => :'restrictions', :'ip_addresses' => :'ip_addresses', :'call_icons' => :'call_icons' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/one_msg_sdk/models/calling_settings_calling.rb', line 283 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
115 116 117 118 |
# File 'lib/one_msg_sdk/models/calling_settings_calling.rb', line 115 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/one_msg_sdk/models/calling_settings_calling.rb', line 98 def self.openapi_types { :'status' => :'String', :'call_icon_visibility' => :'String', :'callback_permission_status' => :'String', :'srtp_key_exchange_protocol' => :'String', :'call_hours' => :'CallingSettingsCallingCallHours', :'sip' => :'CallingSettingsCallingSip', :'video' => :'CallingSettingsCallingVideo', :'audio' => :'CallingSettingsCallingAudio', :'restrictions' => :'Hash<String, Object>', :'ip_addresses' => :'Hash<String, Object>', :'call_icons' => :'Hash<String, Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/one_msg_sdk/models/calling_settings_calling.rb', line 252 def ==(o) return true if self.equal?(o) self.class == o.class && status == o.status && call_icon_visibility == o.call_icon_visibility && == o. && srtp_key_exchange_protocol == o.srtp_key_exchange_protocol && call_hours == o.call_hours && sip == o.sip && video == o.video && audio == o.audio && restrictions == o.restrictions && ip_addresses == o.ip_addresses && call_icons == o.call_icons end |
#eql?(o) ⇒ Boolean
270 271 272 |
# File 'lib/one_msg_sdk/models/calling_settings_calling.rb', line 270 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
276 277 278 |
# File 'lib/one_msg_sdk/models/calling_settings_calling.rb', line 276 def hash [status, call_icon_visibility, , srtp_key_exchange_protocol, call_hours, sip, video, audio, restrictions, ip_addresses, call_icons].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
189 190 191 192 193 |
# File 'lib/one_msg_sdk/models/calling_settings_calling.rb', line 189 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/one_msg_sdk/models/calling_settings_calling.rb', line 305 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/one_msg_sdk/models/calling_settings_calling.rb', line 197 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["ENABLED", "DISABLED"]) return false unless status_validator.valid?(@status) call_icon_visibility_validator = EnumAttributeValidator.new('String', ["DEFAULT", "DISABLE_ALL"]) return false unless call_icon_visibility_validator.valid?(@call_icon_visibility) = EnumAttributeValidator.new('String', ["ENABLED", "DISABLED"]) return false unless .valid?(@callback_permission_status) srtp_key_exchange_protocol_validator = EnumAttributeValidator.new('String', ["DTLS", "SDES"]) return false unless srtp_key_exchange_protocol_validator.valid?(@srtp_key_exchange_protocol) true end |